==> vue-image-viewer-3.22.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var $constants = {
  MODE: {
    CONTAIN: {
      name: "contain",
      icon: "icon-fullscreen"
    },
    ORIGINAL: {
      name: "original",
      icon: "icon-minscreen"
    }
  },
  DEFAULT_POPPER_ZINDEX: Number.POSITIVE_INFINITY,
  THUMBNAILTOP: 8,
  MENUTOP: 10
};
var ImageViewer = defineComponent({
  name: $prefix + "ImageViewer",
  props: _extends({}, $props, {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    urlList: {
      type: Array,
      default: function _default2() {
        return [];
      }
    },
    zIndex: {
      type: Number,
      default: $constants.DEFAULT_POPPER_ZINDEX
    },
    previewVisible: {
      type: Boolean,
      default: false
    },
    closeShow: {
      type: Boolean,
      default: false
    },
    arrowShow: {
      type: Boolean,
      default: false
    },
    toolShow: {
      type: Boolean,
      default: false
    },
    showIndex: {
      type: Boolean,
      default: false
    },
    imageFullCurrent: {
      type: Boolean,
      default: false
    },
    startPosition: {
      type: Number,
      default: 0
    },
    asyncClose: {
      type: Boolean,
      default: false
    },
    deleteButton: {
      type: Boolean,
      default: false
    },
    onSwitch: {
      type: Function,
      default: function _default3() {
      }
    },
    onClose: {
      type: Function,
      default: function _default4() {
      }
    },
    isThumbnail: {
      type: Boolean,
      default: false
    },
    isMenuView: {
      type: Boolean,
      default: false
    },
    modalView: {
      type: Boolean,
      default: false
    },
    modalHeight: {
      type: [String, Number],
      default: 400
    },
    bgColor: {
      type: String,
      default: "bg-color-icon-primary"
    },
    keepStyle: {
      type: Boolean,
      default: false
    }
  }),
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "3.22.0";
ImageViewer.install = function(Vue) {
  Vue.component(ImageViewer.name, ImageViewer);
};
ImageViewer.version = version;
export {
  ImageViewer as default
};

==> vue-image-viewer-3.22.1.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var $constants = {
  MODE: {
    CONTAIN: {
      name: "contain",
      icon: "icon-fullscreen"
    },
    ORIGINAL: {
      name: "original",
      icon: "icon-minscreen"
    }
  },
  DEFAULT_POPPER_ZINDEX: Number.POSITIVE_INFINITY,
  THUMBNAILTOP: 8,
  MENUTOP: 10
};
var ImageViewer = defineComponent({
  name: $prefix + "ImageViewer",
  props: _extends({}, $props, {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    urlList: {
      type: Array,
      default: function _default2() {
        return [];
      }
    },
    zIndex: {
      type: Number,
      default: $constants.DEFAULT_POPPER_ZINDEX
    },
    previewVisible: {
      type: Boolean,
      default: false
    },
    closeShow: {
      type: Boolean,
      default: false
    },
    arrowShow: {
      type: Boolean,
      default: false
    },
    toolShow: {
      type: Boolean,
      default: false
    },
    showIndex: {
      type: Boolean,
      default: false
    },
    imageFullCurrent: {
      type: Boolean,
      default: false
    },
    startPosition: {
      type: Number,
      default: 0
    },
    asyncClose: {
      type: Boolean,
      default: false
    },
    deleteButton: {
      type: Boolean,
      default: false
    },
    onSwitch: {
      type: Function,
      default: function _default3() {
      }
    },
    onClose: {
      type: Function,
      default: function _default4() {
      }
    },
    isThumbnail: {
      type: Boolean,
      default: false
    },
    isMenuView: {
      type: Boolean,
      default: false
    },
    modalView: {
      type: Boolean,
      default: false
    },
    modalHeight: {
      type: [String, Number],
      default: 400
    },
    bgColor: {
      type: String,
      default: "bg-color-icon-primary"
    },
    keepStyle: {
      type: Boolean,
      default: false
    }
  }),
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "3.undefined";
ImageViewer.install = function(Vue) {
  Vue.component(ImageViewer.name, ImageViewer);
};
ImageViewer.version = version;
export {
  ImageViewer as default
};
